==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/PERIODINTERVAL.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="INTERVAL" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="UOM">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;enumeration value="D"/>
 *               &lt;enumeration value="W"/>
 *               &lt;enumeration value="M"/>
 *               &lt;enumeration value="Q"/>
 *               &lt;enumeration value="Y"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NESTINGBUFFER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "interval",
    "uom",
    "duedate",
    "nestingbuffer"
})
@XmlRootElement(name = "PERIODINTERVAL")
public class PERIODINTERVAL {

    @XmlElement(name = "INTERVAL")
    protected long interval;
    @XmlElement(name = "UOM", required = true)
    protected String uom;
    @XmlElement(name = "DUEDATE")
    protected DATETIME duedate;
    @XmlElement(name = "NESTINGBUFFER")
    protected NESTINGBUFFER_Type nestingbuffer;

    /**
     * Obtient la valeur de la propriété interval.
     * 
     */
    public long getINTERVAL() {
        return interval;
    }

    /**
     * Définit la valeur de la propriété interval.
     * 
     */
    public void setINTERVAL(long value) {
        this.interval = value;
    }

    /**
     * Obtient la valeur de la propriété uom.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOM() {
        return uom;
    }

    /**
     * Définit la valeur de la propriété uom.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOM(String value) {
        this.uom = value;
    }

    /**
     * Obtient la valeur de la propriété duedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATE() {
        return duedate;
    }

    /**
     * Définit la valeur de la propriété duedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATE(DATETIME value) {
        this.duedate = value;
    }

    /**
     * Obtient la valeur de la propriété nestingbuffer.
     * 
     * @return
     *     possible object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public NESTINGBUFFER_Type getNESTINGBUFFER() {
        return nestingbuffer;
    }

    /**
     * Définit la valeur de la propriété nestingbuffer.
     * 
     * @param value
     *     allowed object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public void setNESTINGBUFFER(NESTINGBUFFER_Type value) {
        this.nestingbuffer = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/PERIODINTERVAL.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="INTERVAL" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="UOM">
 *           &lt;simpleType>
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *               &lt;enumeration value="D"/>
 *               &lt;enumeration value="W"/>
 *               &lt;enumeration value="M"/>
 *               &lt;enumeration value="Q"/>
 *               &lt;enumeration value="Y"/>
 *             &lt;/restriction>
 *           &lt;/simpleType>
 *         &lt;/element>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NESTINGBUFFER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "interval",
    "uom",
    "duedate",
    "nestingbuffer"
})
@XmlRootElement(name = "PERIODINTERVAL")
public class PERIODINTERVAL {

    @XmlElement(name = "INTERVAL")
    protected long interval;
    @XmlElement(name = "UOM", required = true)
    protected String uom;
    @XmlElement(name = "DUEDATE")
    protected DATETIME duedate;
    @XmlElement(name = "NESTINGBUFFER")
    protected NESTINGBUFFER_Type nestingbuffer;

    /**
     * Gets the value of the interval property.
     * 
     */
    public long getINTERVAL() {
        return interval;
    }

    /**
     * Sets the value of the interval property.
     * 
     */
    public void setINTERVAL(long value) {
        this.interval = value;
    }

    /**
     * Gets the value of the uom property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUOM() {
        return uom;
    }

    /**
     * Sets the value of the uom property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUOM(String value) {
        this.uom = value;
    }

    /**
     * Gets the value of the duedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATE() {
        return duedate;
    }

    /**
     * Sets the value of the duedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATE(DATETIME value) {
        this.duedate = value;
    }

    /**
     * Gets the value of the nestingbuffer property.
     * 
     * @return
     *     possible object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public NESTINGBUFFER_Type getNESTINGBUFFER() {
        return nestingbuffer;
    }

    /**
     * Sets the value of the nestingbuffer property.
     * 
     * @param value
     *     allowed object is
     *     {@link NESTINGBUFFER_Type }
     *     
     */
    public void setNESTINGBUFFER(NESTINGBUFFER_Type value) {
        this.nestingbuffer = value;
    }

}
